@@ -78,7 +78,7 @@ consensus_evaluate <- function(data, ..., cons.cl = NULL, ref.cl = NULL,
 
   # Calculate PAC
   pac <- cons.mat %>%
-    purrr::at_depth(2, PAC) %>%
+    purrr::modify_depth(2, PAC) %>%
     purrr::map_df(data.frame, .id = "k")
 
   # If reference given, k is number of distinct classes
@@ -200,13 +200,12 @@ consensus_trim <- function(E, ii, k, k.method, reweigh, n) {
 
   # Which algorithm is the best for each index?
   bests <- purrr::map2_int(z.main, names(z.main), clusterCrit::bestCriterion)
-
   max.bests <- z.main %>%
     magrittr::extract(purrr::map_int(., which.max) == bests) %>%
-    cbind(z.other) %>%
     magrittr::multiply_by(-1)
   min.bests <- z.main %>%
-    magrittr::extract(purrr::map_int(., which.min) == bests)
+    magrittr::extract(purrr::map_int(., which.min) == bests) %>%
+    cbind(z.other)
 
   # Determine trimmed ensemble using rank aggregation, only if there are more
   # algorithms than we want to keep
@@ -284,7 +283,8 @@ gcd <- function(x, y) {
 #' Compute the compactness validity index for a clustering result.
 #'
 #' This index is agnostic to any reference clustering results, calculating
-#' cluster performance on the basis of compactness and separability.
+#' cluster performance on the basis of compactness and separability. Smaller
+#' values indicate a better clustering structure.
 #'
 #' @param data a dataset with rows as observations, columns as variables
 #' @param labels a vector of cluster labels from a clustering result
