@@ -121,45 +121,3 @@ dice <- function(data, nk, reps = 10, algorithms = NULL, k.method = NULL,
   Ecomp <- abind::abind(Ecomp, along = 3)
   dplyr::lst(E, Eknn, Ecomp, clusters, indices)
 }
-
-#' Prepare data for consensus clustering
-#'
-#' Remove variables with low signal and (optionally) scale before consensus
-#' clustering.
-#'
-#' @param data data matrix with rows as samples and columns as variables
-#' @param scale logical; should the data be centered and scaled?
-#' @param type if we use "conventional" measures (default), then the mean and
-#'   standard deviation are used for centering and scaling, respectively. If
-#'   "robust" measures are specified, the median and median absolute deviation
-#'   (MAD) are used.
-#' @param min.var minimum variability measure threshold used to filter the
-#'   feature space for only highly variable features. Only features with a
-#'   minimum variability measure across all samples greater than \code{min.var}
-#'   will be used. If \code{type = "conventional"}, the standard deviation is
-#'   the measure used, and if \code{type = "robust"}, the MAD is the measure
-#'   used.
-#' @return dataset prepared for usage in \code{consensus_cluster}
-#' @author Derek Chiu
-#' @export
-#' @examples
-#' set.seed(2)
-#' x <- replicate(10, rnorm(100))
-#' x.prep <- prepare_data(x)
-#' dim(x)
-#' dim(x.prep)
-prepare_data <- function(data, scale = TRUE,
-                         type = c("conventional", "robust"),
-                         min.var = 1) {
-  type <- match.arg(type)
-  var.fun <- switch(type, conventional = stats::sd, robust = stats::mad)
-  dat <- data %>%
-    magrittr::extract(stats::complete.cases(.),
-                      apply(., 2, var.fun, na.rm = TRUE) > min.var)
-  if (scale) {
-    dat <- switch(type,
-                  conventional = scale(dat),
-                  robust = quantable::robustscale(dat))
-  }
-  dat
-}
